@@ -265,9 +265,6 @@ def main():
         with open(args_conf, "r") as conff:
             conf = luxem.load(conff)[0]
         want = dict()
-        want.setdefault("apt", dict()).update(
-            {k: k for k in plugins["apt"].base_want()}
-        )
         add = dict()
         remove = dict()
         for package in conf["installed"]:
@@ -285,6 +282,8 @@ def main():
             print(f"Scanning current package state for {plugin.id()}...")
             installed = set(plugin.installed())
             plugin_want = want.get(plugin.id(), dict())
+            if plugin.id() == "apt":
+                plugin_want.update({k: k for k in plugins["apt"].base_want()})
             add[plugin.id()] = [plugin_want[p] for p in plugin_want.keys() - installed]
             remove[plugin.id()] = installed - plugin_want.keys()
 
